@@ -27,7 +27,7 @@ Resources
 '''
 
 __title__ = 'becas'
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 __author__ = 'Tiago Nunes'
 __license__ = 'CC-BY-NC'
 __copyright__ = 'Copyright 2013, Tiago Nunes, Universidade de Aveiro'
@@ -542,8 +542,12 @@ def handle_annotation_results(results, output_file):
 
     results = json.dumps(results) if isinstance(results, dict) else results
     if output_file:
-        output_file.write(results.encode('utf-8'))
-        output_file.close()
+        try:
+            output_file.write(results.encode('utf-8'))
+        except IOError as e:
+            abort('IOError writing to output file: %s' % e)
+        finally:
+            output_file.close()
     else:
         sys.stdout.write(results)
         sys.stdout.flush()
@@ -559,8 +563,7 @@ def cli_annotate_text(args):
     except ValueError as e:
         argparser().error(e)
     except BecasException as e:
-        sys.stderr.write('%s: %s\n' % (type(e).__name__, e))
-        sys.exit(1)
+        abort(e)
     handle_annotation_results(results, args.output_file)
 
 
@@ -574,8 +577,7 @@ def cli_export_text(args):
     except ValueError as e:
         argparser().error(e)
     except BecasException as e:
-        sys.stderr.write('%s: %s\n' % (type(e).__name__, e))
-        sys.exit(1)
+        abort(e)
     handle_annotation_results(results, args.output_file)
 
 
@@ -588,8 +590,7 @@ def cli_annotate_publication(args):
     except ValueError as e:
         argparser().error(e)
     except BecasException as e:
-        sys.stderr.write('%s: %s\n' % (type(e).__name__, e))
-        sys.exit(1)
+        abort(e)
     handle_annotation_results(results, args.output_file)
 
 
@@ -602,21 +603,28 @@ def cli_export_publication(args):
     except ValueError as e:
         argparser().error(e)
     except BecasException as e:
-        sys.stderr.write('%s: %s\n' % (type(e).__name__, e))
-        sys.exit(1)
+        abort(e)
     handle_annotation_results(results, args.output_file)
 
 
 def main():
     '''Command-line interface entry point.'''
 
-    parser = argparser()
-    args = parser.parse_args()
+    args = argparser().parse_args()
     args.func(args)
 
 
+def abort(msg, ret=1):
+    '''Print message to stderr and abort program execution.'''
+
+    if isinstance(msg, Exception):
+        msg = '%s: %s' % (type(msg).__name__, msg)
+    sys.stderr.write(msg + '\n')
+    sys.exit(ret)
+
+
 if __name__ == '__main__':
     try:
         main()
     except KeyboardInterrupt:
-        sys.stderr.write('Manually interrupted by ^C. Aborting.\n')
+        abort('Manually interrupted by ^C. Aborting.')
